@@ -59,7 +59,8 @@ def generate(source_path, base) -> None:
                 full_name = f"{(namespace + '.') if namespace else ''}{name}"
 
                 Path(DESTINATION, full_path).parent.mkdir(
-                    parents=True, exist_ok=True
+                    parents=True,
+                    exist_ok=True,
                 )
 
                 with Path(DESTINATION, full_path).open("w", encoding="utf-8") as f:
@@ -68,9 +69,9 @@ def generate(source_path, base) -> None:
                             title=full_name,
                             title_markup="=" * len(full_name),
                             full_class_path="pyrogram.raw.{}".format(
-                                ".".join(full_path.split("/")[:-1]) + "." + name
+                                ".".join(full_path.split("/")[:-1]) + "." + name,
                             ),
-                        )
+                        ),
                     )
 
                 if last not in all_entities:
@@ -82,7 +83,7 @@ def generate(source_path, base) -> None:
 
     for k, v in sorted(all_entities.items()):
         v = sorted(v)
-        entities = [f'{i} <{snake(i).replace("_", "-")}>' for i in v]
+        entities = [f"{i} <{snake(i).replace('_', '-')}>" for i in v]
 
         if k != base:
             inner_path = base + "/" + k + "/index" + ".rst"
@@ -106,7 +107,7 @@ def generate(source_path, base) -> None:
                     title_markup="=" * len(k),
                     module=module,
                     entities="\n    ".join(entities),
-                )
+                ),
             )
 
             f.write("\n")
@@ -344,6 +345,11 @@ def pyrogram_api() -> None:
             get_bot_info
             set_bot_info
             get_collectible_item_info
+            get_available_gifts
+            get_user_gifts
+            sell_gift
+            send_gift
+            toggle_gift_is_saved
         """,
         "business": """
         Telegram Business
@@ -476,6 +482,7 @@ def pyrogram_api() -> None:
             AvailableEffect
             Document
             Animation
+            AlternativeVideo
             LabeledPrice
             Video
             Voice
@@ -489,6 +496,8 @@ def pyrogram_api() -> None:
             ScreenshotTaken
             Game
             GiftedPremium
+            Gift
+            UserGift
             Giveaway
             GiveawayLaunched
             GiveawayResult
@@ -739,6 +748,10 @@ def pyrogram_api() -> None:
             Message.wait_for_click
             Message.pay
         """,
+        "usergift": """
+        UserGift
+            UserGift.toggle
+        """,
         "chat": """
         Chat
             Chat.ask
@@ -845,8 +858,8 @@ def pyrogram_api() -> None:
                 {
                     f"{k}_hlist": "\n    ".join(
                         f"- :meth:`~{bm}`" for bm in bound_methods
-                    )
-                }
+                    ),
+                },
             )
 
             fmt_keys.update(
@@ -854,8 +867,8 @@ def pyrogram_api() -> None:
                     f"{k}_toctree": "\n    ".join(
                         "{} <{}>".format(bm.split(".")[1], bm)
                         for bm in bound_methods
-                    )
-                }
+                    ),
+                },
             )
 
             for bm in bound_methods:
