@@ -21,7 +21,10 @@ class Handler:
             if inspect.iscoroutinefunction(self.filters.__call__):
                 return await self.filters(client, update)
             return await client.loop.run_in_executor(
-                client.executor, self.filters, client, update
+                client.executor,
+                self.filters,
+                client,
+                update,
             )
 
         return True
