@@ -6,7 +6,8 @@ from pyrogram import raw
 
 class AcceptTermsOfService:
     async def accept_terms_of_service(
-        self: pyrogram.Client, terms_of_service_id: str
+        self: pyrogram.Client,
+        terms_of_service_id: str,
     ) -> bool:
         """Accept the given terms of service.
 
@@ -18,8 +19,8 @@ class AcceptTermsOfService:
         """
         r = await self.invoke(
             raw.functions.help.AcceptTermsOfService(
-                id=raw.types.DataJSON(data=terms_of_service_id)
-            )
+                id=raw.types.DataJSON(data=terms_of_service_id),
+            ),
         )
 
         return bool(r)
