@@ -6,7 +6,9 @@ from pyrogram import raw, types
 
 class CreateSupergroup:
     async def create_supergroup(
-        self: pyrogram.Client, title: str, description: str = ""
+        self: pyrogram.Client,
+        title: str,
+        description: str = "",
     ) -> types.Chat:
         """Create a new supergroup.
 
@@ -33,8 +35,10 @@ class CreateSupergroup:
         """
         r = await self.invoke(
             raw.functions.channels.CreateChannel(
-                title=title, about=description, megagroup=True
-            )
+                title=title,
+                about=description,
+                megagroup=True,
+            ),
         )
 
         return types.Chat._parse_chat(self, r.chats[0])
