@@ -6,7 +6,9 @@ from pyrogram import raw
 
 class DeleteForumTopic:
     async def delete_forum_topic(
-        self: pyrogram.Client, chat_id: int | str, topic_id: int
+        self: pyrogram.Client,
+        chat_id: int | str,
+        topic_id: int,
     ) -> bool:
         """Delete a forum topic.
 
@@ -33,7 +35,7 @@ class DeleteForumTopic:
                 raw.functions.channels.DeleteTopicHistory(
                     channel=await self.resolve_peer(chat_id),
                     top_msg_id=topic_id,
-                )
+                ),
             )
         except Exception as e:
             print(e)
