@@ -6,7 +6,9 @@ from pyrogram import raw
 
 class EditGeneralTopic:
     async def edit_general_topic(
-        self: pyrogram.Client, chat_id: int | str, title: str
+        self: pyrogram.Client,
+        chat_id: int | str,
+        title: str,
     ) -> bool:
         """Edit a general forum topic.
 
@@ -33,6 +35,6 @@ class EditGeneralTopic:
                 channel=await self.resolve_peer(chat_id),
                 topic_id=1,
                 title=title,
-            )
+            ),
         )
         return True
