@@ -24,6 +24,7 @@ class MarkChatUnread:
 
         return await self.invoke(
             raw.functions.messages.MarkDialogUnread(
-                peer=await self.resolve_peer(chat_id), unread=True
-            )
+                peer=await self.resolve_peer(chat_id),
+                unread=True,
+            ),
         )
