@@ -6,7 +6,9 @@ from pyrogram import raw
 
 class SetChatProtectedContent:
     async def set_chat_protected_content(
-        self: pyrogram.Client, chat_id: int | str, enabled: bool
+        self: pyrogram.Client,
+        chat_id: int | str,
+        enabled: bool,
     ) -> bool:
         """Set the chat protected content setting.
 
@@ -26,8 +28,9 @@ class SetChatProtectedContent:
 
         await self.invoke(
             raw.functions.messages.ToggleNoForwards(
-                peer=await self.resolve_peer(chat_id), enabled=enabled
-            )
+                peer=await self.resolve_peer(chat_id),
+                enabled=enabled,
+            ),
         )
 
         return True
