@@ -21,5 +21,5 @@ class GetContactsCount:
         """
 
         return len(
-            (await self.invoke(raw.functions.contacts.GetContacts(hash=0))).contacts
+            (await self.invoke(raw.functions.contacts.GetContacts(hash=0))).contacts,
         )
