@@ -6,7 +6,8 @@ from pyrogram import raw, types
 
 class GetStickerSet:
     async def get_sticker_set(
-        self: pyrogram.Client, set_short_name: str
+        self: pyrogram.Client,
+        set_short_name: str,
     ) -> types.StickerSet:
         """Get info about a stickerset.
 
@@ -27,10 +28,10 @@ class GetStickerSet:
         r = await self.invoke(
             raw.functions.messages.GetStickerSet(
                 stickerset=raw.types.InputStickerSetShortName(
-                    short_name=set_short_name
+                    short_name=set_short_name,
                 ),
                 hash=0,
-            )
+            ),
         )
 
         return types.StickerSet._parse(r.set)
