@@ -20,7 +20,7 @@ class GetMe:
                 print(me)
         """
         r = await self.invoke(
-            raw.functions.users.GetFullUser(id=raw.types.InputUserSelf())
+            raw.functions.users.GetFullUser(id=raw.types.InputUserSelf()),
         )
 
         users = {u.id: u for u in r.users}
