@@ -29,6 +29,6 @@ class SetUsername:
 
         return bool(
             await self.invoke(
-                raw.functions.account.UpdateUsername(username=username or "")
-            )
+                raw.functions.account.UpdateUsername(username=username or ""),
+            ),
         )
