@@ -10,12 +10,16 @@ from .tl_object import TLObject
 class Message(TLObject):
     ID = 0x5BB8E511  # hex(crc32(b"message msg_id:long seqno:int bytes:int body:Object = Message"))
 
-    __slots__ = ["msg_id", "seq_no", "length", "body"]
+    __slots__ = ["body", "length", "msg_id", "seq_no"]
 
     QUALNAME = "Message"
 
     def __init__(
-        self, body: TLObject, msg_id: int, seq_no: int, length: int
+        self,
+        body: TLObject,
+        msg_id: int,
+        seq_no: int,
+        length: int,
     ) -> None:
         self.msg_id = msg_id
         self.seq_no = seq_no
