@@ -45,5 +45,5 @@ class Vector(bytes, TLObject):
     def __new__(cls, value: list, t: Any = None) -> bytes:  # type: ignore
         return b"".join(
             [Int(cls.ID, False), Int(len(value))]
-            + [cast(bytes, t(i)) if t else i.write() for i in value]
+            + [cast(bytes, t(i)) if t else i.write() for i in value],
         )
