@@ -24,6 +24,7 @@ class StrippedThumbnail(Object):
 
     @staticmethod
     def _parse(
-        client, stripped_thumbnail: raw.types.PhotoStrippedSize
+        client,
+        stripped_thumbnail: raw.types.PhotoStrippedSize,
     ) -> StrippedThumbnail:
         return StrippedThumbnail(data=stripped_thumbnail.bytes, client=client)
